@@ -30,109 +30,17 @@
 
 #include "indicator.h"
 
-/* default settings */
-#define DEFAULT_SETTING1 NULL
-#define DEFAULT_SETTING2 1
-#define DEFAULT_SETTING3 FALSE
-
 /* prototypes */
 static void
 indicator_construct (XfcePanelPlugin *plugin);
 
 static gboolean
-load_module (const gchar * name, GtkWidget * menu);
-
-static gboolean
-on_menu_press (GtkWidget *widget, GdkEventButton *event, IndicatorPlugin *indicator);
-
+load_module (const gchar * name, IndicatorPlugin * indicator);
 
 /* register the plugin */
 XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (indicator_construct);
 
 
-#if 0
-void
-indicator_save (XfcePanelPlugin *plugin,
-             IndicatorPlugin    *indicator)
-{
-  XfceRc *rc;
-  gchar  *file;
-
-  /* get the config file location */
-  file = xfce_panel_plugin_save_location (plugin, TRUE);
-
-  if (G_UNLIKELY (file == NULL))
-    {
-       DBG ("Failed to open config file");
-       return;
-    }
-
-  /* open the config file, read/write */
-  rc = xfce_rc_simple_open (file, FALSE);
-  g_free (file);
-
-  if (G_LIKELY (rc != NULL))
-    {
-      /* save the settings */
-      DBG(".");
-      if (indicator->setting1)
-        xfce_rc_write_entry    (rc, "setting1", indicator->setting1);
-
-      xfce_rc_write_int_entry  (rc, "setting2", indicator->setting2);
-      xfce_rc_write_bool_entry (rc, "setting3", indicator->setting3);
-
-      /* close the rc file */
-      xfce_rc_close (rc);
-    }
-}
-
-
-
-static void
-indicator_read (IndicatorPlugin *indicator)
-{
-  XfceRc      *rc;
-  gchar       *file;
-  const gchar *value;
-
-  /* get the plugin config file location */
-  file = xfce_panel_plugin_save_location (indicator->plugin, TRUE);
-
-  if (G_LIKELY (file != NULL))
-    {
-      /* open the config file, readonly */
-      rc = xfce_rc_simple_open (file, TRUE);
-
-      /* cleanup */
-      g_free (file);
-
-      if (G_LIKELY (rc != NULL))
-        {
-          /* read the settings */
-          value = xfce_rc_read_entry (rc, "setting1", DEFAULT_SETTING1);
-          indicator->setting1 = g_strdup (value);
-
-          indicator->setting2 = xfce_rc_read_int_entry (rc, "setting2", DEFAULT_SETTING2);
-          indicator->setting3 = xfce_rc_read_bool_entry (rc, "setting3", DEFAULT_SETTING3);
-
-          /* cleanup */
-          xfce_rc_close (rc);
-
-          /* leave the function, everything went well */
-          return;
-        }
-    }
-
-  /* something went wrong, apply default values */
-  DBG ("Applying default settings");
-
-  indicator->setting1 = g_strdup (DEFAULT_SETTING1);
-  indicator->setting2 = DEFAULT_SETTING2;
-  indicator->setting3 = DEFAULT_SETTING3;
-}
-#endif
-
-
 static IndicatorPlugin *
 indicator_new (XfcePanelPlugin *plugin)
 {
@@ -152,43 +60,21 @@ indicator_new (XfcePanelPlugin *plugin)
   /* Init some theme/icon stuff */
   gtk_icon_theme_append_search_path(gtk_icon_theme_get_default(),
                                   INDICATOR_ICONS_DIR);
-  /* g_debug("Icons directory: %s", INDICATOR_ICONS_DIR); */
-  gtk_rc_parse_string (
-    "style \"indicator-applet-style\"\n"
-    "{\n"
-    "    GtkMenuBar::shadow-type = none\n"
-    "    GtkMenuBar::internal-padding = 0\n"
-    "    GtkWidget::focus-line-width = 0\n"
-    "    GtkWidget::focus-padding = 0\n"
-    "}\n"
-    "style \"indicator-applet-menubar-style\"\n"
-    "{\n"
-    "    GtkMenuBar::shadow-type = none\n"
-    "    GtkMenuBar::internal-padding = 0\n"
-    "    GtkWidget::focus-line-width = 0\n"
-    "    GtkWidget::focus-padding = 0\n"
-    "    GtkMenuItem::horizontal-padding = 0\n"
-    "}\n"
-    "style \"indicator-applet-menuitem-style\"\n"
-    "{\n"
-    "    GtkWidget::focus-line-width = 0\n"
-    "    GtkWidget::focus-padding = 0\n"
-    "    GtkMenuItem::horizontal-padding = 0\n"
-    "}\n"
-    "widget \"*.indicator-applet\" style \"indicator-applet-style\""
-    "widget \"*.indicator-applet-menuitem\" style \"indicator-applet-menuitem-style\""
-    "widget \"*.indicator-applet-menubar\" style \"indicator-applet-menubar-style\"");
-  gtk_widget_set_name(GTK_WIDGET (plugin), "indicator-applet-menubar");
-  /* create some panel widgets */
+  gtk_widget_set_name(GTK_WIDGET (indicator), "indicator-plugin");
   
-  /* Build menu */
-  indicator->menu = gtk_menu_bar_new();
-  GTK_WIDGET_SET_FLAGS (indicator->menu, GTK_WIDGET_FLAGS(indicator->menu) | GTK_CAN_FOCUS);
-  gtk_widget_set_name(GTK_WIDGET (indicator->menu), "indicator-applet-menubar");
-  g_signal_connect(indicator->menu, "button-press-event", G_CALLBACK(on_menu_press), NULL);
-  //g_signal_connect_after(indicator->menu, "expose-event", G_CALLBACK(menu_on_expose), menu);
-  gtk_container_set_border_width(GTK_CONTAINER(indicator->menu), 0);
+  indicator->buttonbox = gtk_hbox_new(FALSE,0);
+  gtk_widget_set_can_focus(GTK_WIDGET(indicator->buttonbox), TRUE);
+  gtk_rc_parse_string (
+    "style \"indicator-plugin-style\"\n"
+    "{\n"
+    "    GtkButton::internal-border= 0\n"
+    "    GtkWidget::focus-line-width = 0\n"
+    "    GtkWidget::focus-padding = 0\n"
+    "}\n"
+    "widget \"*.indicator-button\" style \"indicator-plugin-style\"");
 
+  gtk_widget_set_name(GTK_WIDGET (indicator->buttonbox), "indicator-button");
+  gtk_container_set_border_width(GTK_CONTAINER(indicator->buttonbox), 0);
   
   /* load 'em */
   if (g_file_test(INDICATOR_DIR, (G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
@@ -196,7 +82,7 @@ indicator_new (XfcePanelPlugin *plugin)
 
     const gchar * name;
     while ((name = g_dir_read_name(dir)) != NULL) {
-      if (load_module(name, indicator->menu))
+      if (load_module(name, indicator))
         indicators_loaded++;
     }
     g_dir_close (dir);
@@ -205,12 +91,16 @@ indicator_new (XfcePanelPlugin *plugin)
   if (indicators_loaded == 0) {
     /* A label to allow for click through */
     indicator->item = xfce_create_panel_button();
-    gtk_button_set_label(indicator->item, _("No Indicators"));
-    gtk_widget_show(indicator->item);
+    gtk_button_set_label(GTK_BUTTON(indicator->item), _("No Indicators"));
     gtk_container_add (GTK_CONTAINER (plugin), indicator->item);
+    gtk_widget_show(indicator->item);
   } else {
-    gtk_widget_show(indicator->menu);
-    gtk_container_add (GTK_CONTAINER (plugin), indicator->menu);
+    indicator->ebox = gtk_event_box_new();
+    gtk_widget_set_can_focus(GTK_WIDGET(indicator->ebox), TRUE);
+    gtk_container_add (GTK_CONTAINER (indicator->ebox), GTK_WIDGET(indicator->buttonbox));
+    gtk_container_add (GTK_CONTAINER (plugin), GTK_WIDGET(indicator->ebox));
+    gtk_widget_show(GTK_WIDGET(indicator->buttonbox));
+    gtk_widget_show(GTK_WIDGET(indicator->ebox));
   }
   return indicator;
 }
@@ -239,8 +129,10 @@ indicator_orientation_changed (XfcePanelPlugin *plugin,
                             GtkOrientation   orientation,
                             IndicatorPlugin    *indicator)
 {
-  /* change the orienation of the box */
-  //xfce_hvbox_set_orientation (XFCE_HVBOX (indicator->hvbox), orientation);
+  gint sizex=-1, sizey=-1;
+  gtk_orientable_set_orientation (GTK_ORIENTABLE(indicator->buttonbox), orientation);
+  gtk_widget_get_size_request (GTK_WIDGET (plugin), &sizex, &sizey);
+  gtk_widget_set_size_request (GTK_WIDGET (plugin), sizey, sizex);  
 }
 
 
@@ -261,26 +153,32 @@ indicator_size_changed (XfcePanelPlugin *plugin,
   else
     gtk_widget_set_size_request (GTK_WIDGET (plugin), size, -1);
 
-  /* we handled the orientation */
   return TRUE;
 }
 
-
 static gboolean
-on_menu_press (GtkWidget *widget, GdkEventButton *event, IndicatorPlugin *indicator)
+on_button_press (GtkWidget *widget, GdkEventButton *event, IndicatorPlugin *indicator)
 {
-    TRACE ("enters on_button_press");
-    if (indicator != NULL && event->button == 1) /* left click only */
+  if (indicator != NULL)
+  {
+    if( event->button == 1) /* left click only */
     {
-     /*   gtk_menu_popup (GTK_MENU(indicator->menu), NULL, NULL, NULL, NULL, 0,
-                        event->time);*/
-        return TRUE;
+      gtk_menu_popup (GTK_MENU(g_object_get_data (G_OBJECT(widget),"menu")), NULL,
+                      NULL, NULL, NULL, 1, event->time);
+      /* no approvement to the above */
+      /*
+      gtk_menu_popup (GTK_MENU(g_object_get_data (G_OBJECT(widget),"menu")), NULL, NULL,
+                      xfce_panel_plugin_position_menu,
+                      indicator->plugin, 1, gtk_get_current_event_time ());
+      */
+      return TRUE;
     }
-    TRACE ("leaves on_button_press");
-    return FALSE ;
+    /* event doesn't make it to the ebox, so I just push it. */
+    gtk_widget_event (indicator->ebox, (GdkEvent*)event);
+  }
+  return FALSE;
 }
 
-
 static void
 indicator_construct (XfcePanelPlugin *plugin)
 {
@@ -293,7 +191,7 @@ indicator_construct (XfcePanelPlugin *plugin)
   indicator = indicator_new (plugin);
 
   /* show the panel's right-click menu on this menu */
-  xfce_panel_plugin_add_action_widget (plugin, indicator->menu);
+  xfce_panel_plugin_add_action_widget (plugin, indicator->ebox);
   xfce_panel_plugin_add_action_widget (plugin, indicator->item);
 
   /* connect plugin signals */
@@ -326,28 +224,23 @@ entry_scrolled (GtkWidget *menuitem, GdkEventScroll *event, gpointer data)
 static void
 entry_added (IndicatorObject * io, IndicatorObjectEntry * entry, gpointer user_data)
 {
-  GtkWidget * menuitem = gtk_menu_item_new();
-  GtkWidget * hbox = gtk_hbox_new(FALSE, 3);
-
-  g_signal_connect(G_OBJECT(menuitem), "scroll-event", G_CALLBACK(entry_scrolled), entry);
+  GtkWidget * button = gtk_button_new();
+  gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+  gtk_widget_set_name(GTK_WIDGET (button), "indicator-button");
 
   if (entry->image != NULL)
-    gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(entry->image), FALSE, FALSE, 0);
+    gtk_button_set_image(GTK_BUTTON(button), GTK_WIDGET(entry->image));
 
   if (entry->label != NULL)
-    gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(entry->label), FALSE, FALSE, 0);
-
-  gtk_container_add(GTK_CONTAINER(menuitem), hbox);
-  gtk_widget_show(hbox);
+    gtk_button_set_label(GTK_BUTTON(button), gtk_label_get_label (entry->label));
 
   if (entry->menu != NULL)
-    gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), GTK_WIDGET(entry->menu));
+    g_object_set_data(G_OBJECT(button), "menu", entry->menu);
 
-  gtk_menu_shell_append(GTK_MENU_SHELL(user_data), menuitem);
-  gtk_widget_show(menuitem);
-
-  g_object_set_data(G_OBJECT(menuitem), "indicator-custom-object-data", io);
-  g_object_set_data(G_OBJECT(menuitem), "indicator-custom-entry-data", entry);
+  g_signal_connect(button, "button-press-event", G_CALLBACK(on_button_press),
+                   user_data);
+  gtk_box_pack_start(GTK_BOX(((IndicatorPlugin *)user_data)->buttonbox), button, TRUE, TRUE, 0);
+  gtk_widget_show(button);
 }
 
 
@@ -371,7 +264,7 @@ entry_removed (IndicatorObject * io, IndicatorObjectEntry * entry, gpointer user
 
 
 static gboolean
-load_module (const gchar * name, GtkWidget * menu)
+load_module (const gchar * name, IndicatorPlugin * indicator)
 {
 	g_debug("Looking at Module: %s", name);
 	g_return_val_if_fail(name != NULL, FALSE);
@@ -386,16 +279,16 @@ load_module (const gchar * name, GtkWidget * menu)
 	g_free(fullpath);
 
     g_signal_connect(G_OBJECT(io), INDICATOR_OBJECT_SIGNAL_ENTRY_ADDED,
-                     G_CALLBACK(entry_added), menu);
+                     G_CALLBACK(entry_added), indicator);
     g_signal_connect(G_OBJECT(io), INDICATOR_OBJECT_SIGNAL_ENTRY_REMOVED,
-                     G_CALLBACK(entry_removed), menu);
+                     G_CALLBACK(entry_removed), indicator->buttonbox);
 
 	GList * entries = indicator_object_get_entries(io);
 	GList * entry = NULL;
 
 	for (entry = entries; entry != NULL; entry = g_list_next(entry)) {
 		IndicatorObjectEntry * entrydata = (IndicatorObjectEntry *)entry->data;
-		entry_added(io, entrydata, menu);
+		entry_added(io, entrydata, indicator);
 	}
 
 	g_list_free(entries);
